==> jc-1.4.0.tar.gz: gnu/xml/transform/SortKey.h <==
// final class gnu.xml.transform.SortKey

// class file dependencies
// @dep_class d141261efae45817 gnu_xml_transform_SortKey
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_transform_SortKey_H_
#define _JC_gnu_xml_transform_SortKey_H_

// Forward structure declarations
struct _jc_gnu_xml_transform_Stylesheet$object;
struct _jc_gnu_xml_transform_TemplateNode$object;
struct _jc_gnu_xml_xpath_Expr$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_xml_namespace_QName$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_SortKey$sub_refs	_jc_gnu_xml_transform_SortKey$sub_refs;
typedef struct _jc_gnu_xml_transform_SortKey$sub_nonrefs	_jc_gnu_xml_transform_SortKey$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_SortKey$refs	_jc_gnu_xml_transform_SortKey$refs;
typedef struct _jc_gnu_xml_transform_SortKey$nonrefs	_jc_gnu_xml_transform_SortKey$nonrefs;
typedef struct _jc_gnu_xml_transform_SortKey$object	_jc_gnu_xml_transform_SortKey$object;

typedef struct _jc_gnu_xml_transform_SortKey$fields_struct	_jc_gnu_xml_transform_SortKey$fields_struct;
typedef const struct _jc_gnu_xml_transform_SortKey$vmethods	_jc_gnu_xml_transform_SortKey$vmethods;
typedef const struct _jc_gnu_xml_transform_SortKey$vtable	_jc_gnu_xml_transform_SortKey$vtable;
typedef const struct _jc_gnu_xml_transform_SortKey$vtype	_jc_gnu_xml_transform_SortKey$vtype;

// Class fields structure
struct _jc_gnu_xml_transform_SortKey$fields_struct {
	jint	DEFAULT;
	jint	LOWER__5fFIRST;
	jint	UPPER__5fFIRST;
};
extern _jc_gnu_xml_transform_SortKey$fields_struct _jc_gnu_xml_transform_SortKey$class_fields;

// Constructors
extern void _jc_gnu_xml_transform_SortKey$method$_init$84708d264f4705b1(_jc_env *, struct _jc_gnu_xml_transform_SortKey$object *, struct _jc_gnu_xml_xpath_Expr$object *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_transform_TemplateNode$object *);

// Virtual methods
extern void _jc_gnu_xml_transform_SortKey$method$init$6b16d70b163e0bad(_jc_env *, struct _jc_gnu_xml_transform_SortKey$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_javax_xml_namespace_QName$object *, struct _jc_object *, jint, jint, struct _jc_object *, struct _jc_object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_transform_SortKey$method$key$dbc09215d07e5872(_jc_env *, struct _jc_gnu_xml_transform_SortKey$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_SortKey$method_info$init$6b16d70b163e0bad;
extern _jc_method _jc_gnu_xml_transform_SortKey$method_info$key$dbc09215d07e5872;

// Virtual methods structure
struct _jc_gnu_xml_transform_SortKey$vmethods {
	void	(*init$6b16d70b163e0bad)(_jc_env *, struct _jc_gnu_xml_transform_SortKey$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_javax_xml_namespace_QName$object *, struct _jc_object *, jint, jint, struct _jc_object *, struct _jc_object *);
	struct _jc_java_lang_String$object	*(*key$dbc09215d07e5872)(_jc_env *, struct _jc_gnu_xml_transform_SortKey$object *, struct _jc_object *);
};

// Vtable
struct _jc_gnu_xml_transform_SortKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_transform_SortKey$vmethods	gnu_xml_transform_SortKey;
};

// Vtype
struct _jc_gnu_xml_transform_SortKey$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_SortKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_SortKey$sub_refs {
	struct _jc_gnu_xml_xpath_Expr$object	*select;
	struct _jc_gnu_xml_transform_TemplateNode$object	*langTemplate;
	struct _jc_gnu_xml_transform_TemplateNode$object	*dataTypeTemplate;
	struct _jc_gnu_xml_transform_TemplateNode$object	*orderTemplate;
	struct _jc_gnu_xml_transform_TemplateNode$object	*caseOrderTemplate;
	struct _jc_java_lang_String$object	*lang;
	struct _jc_java_lang_String$object	*dataType;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_SortKey$refs {
    _jc_gnu_xml_transform_SortKey$sub_refs	gnu_xml_transform_SortKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_SortKey$sub_nonrefs {
	jboolean	descending;
	jint	caseOrder;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_SortKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_transform_SortKey$sub_nonrefs	gnu_xml_transform_SortKey;
};

// Object instance structure
struct _jc_gnu_xml_transform_SortKey$object {
	_jc_gnu_xml_transform_SortKey$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_SortKey$vtype	*vtype;
	_jc_gnu_xml_transform_SortKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_SortKey$vtype _jc_gnu_xml_transform_SortKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_SortKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_SortKey$class_object;

#endif	/* _JC_gnu_xml_transform_SortKey_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/transform/SortKey.h <==
// final class gnu.xml.transform.SortKey

// class file dependencies
// @dep_class d141261efae45817 gnu_xml_transform_SortKey
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_transform_SortKey_H_
#define _JC_gnu_xml_transform_SortKey_H_

// Forward structure declarations
struct _jc_gnu_xml_transform_Stylesheet$object;
struct _jc_gnu_xml_transform_TemplateNode$object;
struct _jc_gnu_xml_xpath_Expr$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_xml_namespace_QName$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_SortKey$sub_refs	_jc_gnu_xml_transform_SortKey$sub_refs;
typedef struct _jc_gnu_xml_transform_SortKey$sub_nonrefs	_jc_gnu_xml_transform_SortKey$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_SortKey$refs	_jc_gnu_xml_transform_SortKey$refs;
typedef struct _jc_gnu_xml_transform_SortKey$nonrefs	_jc_gnu_xml_transform_SortKey$nonrefs;
typedef struct _jc_gnu_xml_transform_SortKey$object	_jc_gnu_xml_transform_SortKey$object;

typedef struct _jc_gnu_xml_transform_SortKey$fields_struct	_jc_gnu_xml_transform_SortKey$fields_struct;
typedef const struct _jc_gnu_xml_transform_SortKey$vmethods	_jc_gnu_xml_transform_SortKey$vmethods;
typedef const struct _jc_gnu_xml_transform_SortKey$vtable	_jc_gnu_xml_transform_SortKey$vtable;
typedef const struct _jc_gnu_xml_transform_SortKey$vtype	_jc_gnu_xml_transform_SortKey$vtype;

// Class fields structure
struct _jc_gnu_xml_transform_SortKey$fields_struct {
	jint	DEFAULT;
	jint	LOWER__5fFIRST;
	jint	UPPER__5fFIRST;
};
extern _jc_gnu_xml_transform_SortKey$fields_struct _jc_gnu_xml_transform_SortKey$class_fields;

// Constructors
extern void _jc_gnu_xml_transform_SortKey$method$_init$84708d264f4705b1(_jc_env *, struct _jc_gnu_xml_transform_SortKey$object *, struct _jc_gnu_xml_xpath_Expr$object *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_transform_TemplateNode$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_xml_transform_SortKey$method$init$6b16d70b163e0bad(_jc_env *, struct _jc_gnu_xml_transform_SortKey$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_javax_xml_namespace_QName$object *, struct _jc_object *, jint, jint, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_transform_SortKey$method$key$dbc09215d07e5872(_jc_env *, struct _jc_gnu_xml_transform_SortKey$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_SortKey$method_info$init$6b16d70b163e0bad;
extern _jc_method _jc_gnu_xml_transform_SortKey$method_info$key$dbc09215d07e5872;

// Virtual methods structure
struct _jc_gnu_xml_transform_SortKey$vmethods {
	void	(*init$6b16d70b163e0bad)(_jc_env *, struct _jc_gnu_xml_transform_SortKey$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_javax_xml_namespace_QName$object *, struct _jc_object *, jint, jint, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*key$dbc09215d07e5872)(_jc_env *, struct _jc_gnu_xml_transform_SortKey$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_transform_SortKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_transform_SortKey$vmethods	gnu_xml_transform_SortKey;
};

// Vtype
struct _jc_gnu_xml_transform_SortKey$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_SortKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_SortKey$sub_refs {
	struct _jc_gnu_xml_xpath_Expr$object	*select;
	struct _jc_gnu_xml_transform_TemplateNode$object	*langTemplate;
	struct _jc_gnu_xml_transform_TemplateNode$object	*dataTypeTemplate;
	struct _jc_gnu_xml_transform_TemplateNode$object	*orderTemplate;
	struct _jc_gnu_xml_transform_TemplateNode$object	*caseOrderTemplate;
	struct _jc_java_lang_String$object	*lang;
	struct _jc_java_lang_String$object	*dataType;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_SortKey$refs {
    _jc_gnu_xml_transform_SortKey$sub_refs	gnu_xml_transform_SortKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_SortKey$sub_nonrefs {
	jboolean	descending;
	jint	caseOrder;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_SortKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_transform_SortKey$sub_nonrefs	gnu_xml_transform_SortKey;
};

// Object instance structure
struct _jc_gnu_xml_transform_SortKey$object {
	_jc_gnu_xml_transform_SortKey$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_SortKey$vtype	*vtype;
	_jc_gnu_xml_transform_SortKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_SortKey$vtype _jc_gnu_xml_transform_SortKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_SortKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_SortKey$class_object;

#endif	/* _JC_gnu_xml_transform_SortKey_H_ */
